[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,75 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief An example of Fibonacci sequence illustrating how we can use
|
||||
* dynamically created logical data
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int fibo_ref(int n)
|
||||
{
|
||||
if (n < 2)
|
||||
{
|
||||
return n;
|
||||
}
|
||||
else
|
||||
{
|
||||
return fibo_ref(n - 1) + fibo_ref(n - 2);
|
||||
}
|
||||
}
|
||||
|
||||
__global__ void add(slice<int> out, const slice<const int> in1, const slice<const int> in2)
|
||||
{
|
||||
out(0) = in1(0) + in2(0);
|
||||
}
|
||||
|
||||
__global__ void set(slice<int> out, int val)
|
||||
{
|
||||
out(0) = val;
|
||||
}
|
||||
|
||||
logical_data<slice<int>> compute_fibo(context& ctx, int n)
|
||||
{
|
||||
auto out = ctx.logical_data(shape_of<slice<int>>(1));
|
||||
if (n < 2)
|
||||
{
|
||||
ctx.task(out.write())->*[=](cudaStream_t s, auto sout) {
|
||||
set<<<1, 1, 0, s>>>(sout, n);
|
||||
};
|
||||
}
|
||||
else
|
||||
{
|
||||
auto fib1 = compute_fibo(ctx, n - 1);
|
||||
auto fib2 = compute_fibo(ctx, n - 2);
|
||||
ctx.task(fib1.read(), fib2.read(), out.write())->*[=](cudaStream_t s, auto s1, auto s2, auto sout) {
|
||||
add<<<1, 1, 0, s>>>(sout, s1, s2);
|
||||
};
|
||||
}
|
||||
|
||||
return out;
|
||||
}
|
||||
|
||||
int main(int argc, char** argv)
|
||||
{
|
||||
int n = (argc > 1) ? atoi(argv[1]) : 4;
|
||||
|
||||
context ctx; // = graph_ctx();
|
||||
auto result = compute_fibo(ctx, n);
|
||||
ctx.host_launch(result.read())->*[&](auto res) {
|
||||
EXPECT(res(0) == fibo_ref(n));
|
||||
};
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user